@@ -19,11 +19,11 @@
 
       CALL SGLSET('LCNTL', .FALSE.)
       IF (ISYS.EQ.2) THEN
-        CALL SWLSET('SYSFONT', .TRUE.)
+        CALL SWLSET('LSYSFNT', .TRUE.)
         WRITE(*,*) ' FONT NO (1,2) (I) OR DIALOG(3) ? ;'
         READ(*,*) N
       ELSE
-        CALL SWLSET('SYSFONT', .FALSE.)
+        CALL SWLSET('LSYSFNT', .FALSE.)
         WRITE(*,*) ' FONT NO (1,2) (I)  ? ;'
         READ(*,*) N
       END IF
