@@ -1,10 +1,10 @@
 *-----------------------------------------------------------------------
-*     Copyright (C) 2000-2004 GFD Dennou Club. All rights reserved.
+*     Copyright (C) 2000-2016 GFD Dennou Club. All rights reserved.
 *-----------------------------------------------------------------------
       PROGRAM SLPK04
 
       REAL X(5), Y(5)
-      CHARACTER CSGI*1
+      CHARACTER USGI*3
 
       DATA X / -7.5, 7.5, 7.5, -7.5, -7.5/
       DATA Y / -7.5,-7.5, 7.5,  7.5, -7.5/
@@ -26,7 +26,7 @@
       CALL SGSWND(-XMAXF/2., XMAXF/2., -YMAXF/2., YMAXF/2.)
       CALL SGSTRF
       CALL SGPLU(5, X, Y)
-      CALL SGTXZU(0., 0., '15cm '//CSGI(194)//' 15cm', 0.05, 0, 0, 3)
+      CALL SGTXZU(0., 0., '15cm '//USGI(194)//' 15cm', 0.05, 0, 0, 3)
 
       CALL SGCLS
 
