@@ -16,7 +16,7 @@
       CTEXT='(This is drawn by DCL stroke font)'
       CALL SGTXZV(0.5, 0.70, CTEXT, 0.03, 0, 0, 3)
 
-      CALL SWLSET('SYSFONT', .TRUE.)
+      CALL SWLSET('LSYSFNT', .TRUE.)
 
       CALL SWSLFT(FONTNAME)
       CTEXT='Selected font name: '//FONTNAME
