@@ -3,7 +3,9 @@
 
       REAL      UPX(*),UPY(*)
       LOGICAL   LFCATR
-      INTEGER    ITPATX
+      INTEGER   ITPATX
+
+      CALL SGIGET('IFCIDX',IFCIDX)
 
       CALL SWQFCC(LFCATR)
       IF(.NOT.LFCATR) THEN
@@ -25,8 +27,7 @@
       CALL SWSTCL(ICOLOR)
       CALL SWSLCL(ICOLOR)
 
-
-      ITPATX=999*1000+MOD(ITPAT,1000)
+      ITPATX=IFCIDX*1000+MOD(ITPAT,1000)
       CALL SZTNOP(ITPATX)
       CALL SZTNZU(N,UPX,UPY)
       CALL SZTNCL
