@@ -68,6 +68,7 @@
       IYMAX  = MAX(IY1, IY2, IY3, IY4)
       IWIDTH = IXMAX-IXMIN+1
       IHIGHT = IYMAX-IYMIN+1
+        CALL SGQTXY(TXMIN,TXMAX,TYMIN,TYMAX)
 
       CALL SWIOPN(IXMIN, IYMIN, IWIDTH, IHIGHT,
      +            WX1, WY1, WX2, WY2, WX3, WY3, WX4, WY4)
@@ -98,15 +99,14 @@
           IF (ITR.EQ.5) THEN
             CALL SGRGET('UYMAX',UYX)
             CALL SGRGET('UYMIN',UYN)
-            IF (UYX .LT. (UYN+360)) THEN
-              UYX=UYN+360
+            IF (UYX .LT. (UYN+360.)) THEN
+              UYX=UYN+360.
             END IF
           END IF
         CALL UWQGXI(UX,IX,FX)
         CALL UWQGYI(UY,IY,FY)
         CALL STITRN(VX, VY, TUXZ, TUYZ)
         CALL STIRAD(TUXZ,TUYZ,TUX,TUY)
-!          TUX=RMOD(UX,360.)-180.
         IF(TXMIN.LE.TXMAX)THEN
           IF ((TUX.GE.TXMIN).AND.(TUX.LE.TXMAX))THEN
             LEXTEN=.FALSE.
@@ -123,7 +123,7 @@
         IF ((TUY.GE.TYMAX).OR.(TUY.LE.TYMIN))THEN
           LEXTEN=.TRUE.
         END IF
-        IF(LEXTEN.AND.(ITR.GE.5))THEN
+        IF(LEXTEN.AND.(ITR.GT.5))THEN
               IMAGE(I) = 0
         ELSE IF (IX.EQ.IUNDEF .OR. IY.EQ.IUNDEF) THEN
               IMAGE(I) = 0
