@@ -108,23 +108,11 @@
             ELSE
               CH(NBL)=' '
             ENDIF
-
             WRITE(CHR,'(I8)') IP
             CALL CLADJ(CHR)
-            IF(LCNTL) THEN
-*              IF(LSFNT) THEN
-                CH(NBL)(5:18)='10'//'\^{'//CHR(1:LENZ(CHR))
-     +            //'}'
-*              ELSE
-*                CH(NBL)(3:16)='1x'//CSGI(ISUP)//CHR(1:LENZ(CHR))
-*     +            //CSGI(IRST)
-*              END IF
-            ELSE
-              CH(NBL)(4:18)='E'//CHR
-            ENDIF
+            CH(NBL)(5:18)='10\^{'//CHR(1:LENZ(CHR))//'}'
             CALL CLADJ(CH(NBL))
           END IF
-
         ELSE
           IF(JTYPE.EQ.0 .AND. IB.NE.1) THEN
             WRITE(CH(NBL),'(I1)') INT(BL(IB))
