@@ -2,11 +2,13 @@
 *     HIGHER LEVEL APPLICATIONS
 *-----------------------------------------------------------------------
 *     UYAXLB : PLOT Y-AXIS (SPECIFY LABELS)
+*-----------------------------------------------------------------------
+*     Copyright (C) 2000-2016 GFD Dennou Club. All rights reserved.
 *-----------------------------------------------------------------------
       SUBROUTINE UYAXLB(CSIDE,UY1,N1,UY2,CH,NC,N2)
 
       REAL      UY1(*),UY2(*)
-      CHARACTER CSIDE*1,CH*(*)
+      CHARACTER CSIDE*1,CH(*)*(*)
 
       LOGICAL   LABEL,LUYCHK
 
